# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'rereferencingDialogUi.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_rereferencingDialog(object):
    def setupUi(self, rereferencingDialog):
        rereferencingDialog.setObjectName("rereferencingDialog")
        rereferencingDialog.resize(527, 702)
        self.gridLayout_2 = QtWidgets.QGridLayout(rereferencingDialog)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.pushButtonCancel = QtWidgets.QPushButton(rereferencingDialog)
        self.pushButtonCancel.setObjectName("pushButtonCancel")
        self.horizontalLayout.addWidget(self.pushButtonCancel)
        self.pushButtonBatch = QtWidgets.QPushButton(rereferencingDialog)
        self.pushButtonBatch.setObjectName("pushButtonBatch")
        self.horizontalLayout.addWidget(self.pushButtonBatch)
        self.pushButtonApply = QtWidgets.QPushButton(rereferencingDialog)
        self.pushButtonApply.setObjectName("pushButtonApply")
        self.horizontalLayout.addWidget(self.pushButtonApply)
        self.gridLayout_2.addLayout(self.horizontalLayout, 1, 0, 1, 1)
        self.scrollArea = QtWidgets.QScrollArea(rereferencingDialog)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 507, 646))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.gridLayout = QtWidgets.QGridLayout(self.scrollAreaWidgetContents)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBoxRereference = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxRereference.setObjectName("groupBoxRereference")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupBoxRereference)
        self.formLayout_2.setObjectName("formLayout_2")
        self.radioButtonUseAverage = QtWidgets.QRadioButton(self.groupBoxRereference)
        self.radioButtonUseAverage.setChecked(True)
        self.radioButtonUseAverage.setObjectName("radioButtonUseAverage")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.radioButtonUseAverage)
        self.radioButtonUseChannels = QtWidgets.QRadioButton(self.groupBoxRereference)
        self.radioButtonUseChannels.setObjectName("radioButtonUseChannels")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.radioButtonUseChannels)
        self.listWidgetChannels = QtWidgets.QListWidget(self.groupBoxRereference)
        self.listWidgetChannels.setEnabled(False)
        self.listWidgetChannels.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetChannels.setObjectName("listWidgetChannels")
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.listWidgetChannels.addItem(item)
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.listWidgetChannels)
        self.gridLayout.addWidget(self.groupBoxRereference, 0, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem1, 2, 0, 1, 1)
        self.groupBoxBatching = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        self.groupBoxBatching.setObjectName("groupBoxBatching")
        self.gridLayoutBatching = QtWidgets.QGridLayout(self.groupBoxBatching)
        self.gridLayoutBatching.setObjectName("gridLayoutBatching")
        self.batchingWidgetPlaceholder = QtWidgets.QWidget(self.groupBoxBatching)
        self.batchingWidgetPlaceholder.setMinimumSize(QtCore.QSize(300, 300))
        self.batchingWidgetPlaceholder.setObjectName("batchingWidgetPlaceholder")
        self.gridLayoutBatching.addWidget(self.batchingWidgetPlaceholder, 0, 0, 1, 1)
        self.gridLayout.addWidget(self.groupBoxBatching, 1, 0, 1, 1)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.gridLayout_2.addWidget(self.scrollArea, 0, 0, 1, 1)

        self.retranslateUi(rereferencingDialog)
        self.pushButtonCancel.clicked.connect(rereferencingDialog.reject) # type: ignore
        self.pushButtonApply.clicked.connect(rereferencingDialog.accept) # type: ignore
        self.pushButtonBatch.clicked.connect(rereferencingDialog.acceptBatch) # type: ignore
        self.radioButtonUseChannels.toggled['bool'].connect(self.listWidgetChannels.setEnabled) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(rereferencingDialog)

    def retranslateUi(self, rereferencingDialog):
        _translate = QtCore.QCoreApplication.translate
        rereferencingDialog.setWindowTitle(_translate("rereferencingDialog", "Meggie - Rereferencing"))
        self.pushButtonCancel.setText(_translate("rereferencingDialog", "Cancel"))
        self.pushButtonBatch.setText(_translate("rereferencingDialog", "Batch"))
        self.pushButtonApply.setText(_translate("rereferencingDialog", "Apply"))
        self.groupBoxRereference.setTitle(_translate("rereferencingDialog", "Rereferencing options"))
        self.radioButtonUseAverage.setText(_translate("rereferencingDialog", "Use average reference"))
        self.radioButtonUseChannels.setText(_translate("rereferencingDialog", "Select channel(s):"))
        __sortingEnabled = self.listWidgetChannels.isSortingEnabled()
        self.listWidgetChannels.setSortingEnabled(False)
        item = self.listWidgetChannels.item(0)
        item.setText(_translate("rereferencingDialog", "Channel 1"))
        item = self.listWidgetChannels.item(1)
        item.setText(_translate("rereferencingDialog", "Channel 2"))
        item = self.listWidgetChannels.item(2)
        item.setText(_translate("rereferencingDialog", "Channel 3"))
        item = self.listWidgetChannels.item(3)
        item.setText(_translate("rereferencingDialog", "Channel 4"))
        item = self.listWidgetChannels.item(4)
        item.setText(_translate("rereferencingDialog", "Channel 5"))
        item = self.listWidgetChannels.item(5)
        item.setText(_translate("rereferencingDialog", "Channel 6"))
        self.listWidgetChannels.setSortingEnabled(__sortingEnabled)
        self.groupBoxBatching.setTitle(_translate("rereferencingDialog", "Batching"))
